@@ -17,7 +17,10 @@ glue___stsb = Classification(sentence1="sentence1", sentence2="sentence2", label
 
 super_glue___boolq = Classification(sentence1="question", labels="label")
 super_glue___cb = Classification(sentence1="premise", sentence2="hypothesis", labels="label")
-super_glue___multirc = Classification(sentence1="question", labels="label")
+super_glue___multirc = Classification(
+    cat(["paragraph", "question","answer"], " : "),
+    labels='label'
+)
 #super_glue___rte = Classification(sentence1="premise", sentence2="hypothesis", labels="label") # in glue
 super_glue___wic = Classification(
     sentence1=cat(["word","sentence1"], " : "),
@@ -833,4 +836,4 @@ clcd = Classification(
 twentyquestions = Classification("question","subject","answer",dataset_name="maximedb/twentyquestions")
 
 reclor = MultipleChoice(cat(["context","question"]),choices_list="answers",labels="label",
-    dataset_name="metaeval/reclor",splits=['train','validation',None])
\ No newline at end of file
+    dataset_name="metaeval/reclor",splits=['train','validation',None])
